@@ -1,6 +1,6 @@
 import os
 import pickle
-from athletelistsbhp import AthleteListSBh
+from athletelistsbhp import AthleteListSBhp
 
 def sanitize(time_string):
     if '-' in time_string:
@@ -18,7 +18,7 @@ def get_coach_data(filename):
         with open(filename) as f:
             data = f.readline()
         temp = data.strip().split(',')
-        return(AthleteListSBh(temp.pop(0),temp.pop(0),temp))
+        return(AthleteListSBhp(temp.pop(0),temp.pop(0),temp))
     except IOError as Err1:
         print('File IOError (get_coach_data):'+ Err1)
 
